==> lucid.aether-1.4.1.jar: lucid/aether/session.clj <==
(ns lucid.aether.session
  (:require [lucid.aether.local-repo :as local]
            [lucid.aether.listener :as listener])
  (:import [org.apache.maven.repository.internal MavenRepositorySystemUtils]
           [org.eclipse.aether.util.graph.transformer ConflictResolver]
           [org.eclipse.aether.util.graph.manager DependencyManagerUtils]
           [org.eclipse.aether.repository LocalRepository]))

(defn session
  "creates a session from a system:
 
   (session (system/repository-system)
            {})
   => org.eclipse.aether.RepositorySystemSession"
  {:added "1.2"}
  [system {:keys [local-repo listeners] :as opts}]
  (let [session (doto (MavenRepositorySystemUtils/newSession)
                  (.setConfigProperty ConflictResolver/CONFIG_PROP_VERBOSE true)
                  (.setConfigProperty DependencyManagerUtils/CONFIG_PROP_VERBOSE true)
                  (.setRepositoryListener (or (:repository listeners)
                                            listener/default-repository-listener))
                  (.setTransferListener   (or (:transfer listeners)
                                              listener/default-transfer-listener)))
        manager (.newLocalRepositoryManager system
                                            session
                                            (-> (or local-repo local/+default-local-repo+)
                                                (local/local-repo)))
        _ (.setLocalRepositoryManager session manager)]
    session))

==> lucid.aether-1.4.3.jar: lucid/aether/session.clj <==
(ns lucid.aether.session
  (:require [lucid.aether.local-repo :as local]
            [lucid.aether.listener :as listener])
  (:import [org.apache.maven.repository.internal MavenRepositorySystemUtils]
           [org.eclipse.aether.util.graph.transformer ConflictResolver]
           [org.eclipse.aether.util.graph.manager DependencyManagerUtils]
           [org.eclipse.aether.repository LocalRepository]))

(defn session
  "creates a session from a system:
 
   (session (system/repository-system)
            {})
   => org.eclipse.aether.RepositorySystemSession"
  {:added "1.2"}
  [system {:keys [local-repo listeners] :as opts}]
  (let [session (doto (MavenRepositorySystemUtils/newSession)
                  (.setConfigProperty ConflictResolver/CONFIG_PROP_VERBOSE true)
                  (.setConfigProperty DependencyManagerUtils/CONFIG_PROP_VERBOSE true)
                  (.setRepositoryListener (or (:repository listeners)
                                              listener/default-repository-listener))
                  (.setTransferListener   (or (:transfer listeners)
                                              listener/blank-transfer-listener)))
        manager (.newLocalRepositoryManager system
                                            session
                                            (-> (or local-repo local/+default-local-repo+)
                                                (local/local-repo)))
        _ (.setLocalRepositoryManager session manager)]
    session))
